package de.upb.infexba.linguistic;

/**
 * <p>
 * Entity class for storing a monetary subexpression.
 * <p>
 * A monetary subexpression semantically consititutes a text span that 
 * consist of a money term, an optional leading preposition, and - if
 * the latter exists - an optional filler word between those two.
 * <p>
 * Syntactically, a monetary subexpression is given by the string itself
 * as well as its according start and end index, and the type the
 * subexpression refers to as given in <code>SubexpressionType</code>.
 * 
 * @author hwachsmuth
 *
 */
public class MonetarySubexpression {

	/**
	 * The index of the first char of the subexpression.
	 */
	private int begin;
	
	/**
	 * The index of the first char succeeding the subexpression.
	 */
	private int end;
	
	/**
	 * The value of the subexpression, i.e. the expression itself.
	 */
	private String value;
	
	/**
	 * The type of the subexpression as given by the defining preposition.
	 */
	private SubexpressionType type;

	/**
	 * Constructor.
	 * 
	 * @param begin The begin index of the subexpression
	 * @param end The end index of the subexpression
	 * @param value The value, i.e. the subexpression itself.
	 * @param type The type of the subexpression
	 */
	public MonetarySubexpression(int begin, int end, String value, SubexpressionType type) {
		super();
		this.begin = begin;
		this.end = end;
		this.value = value;
		this.type = type;
	}

	/**
	 * Getter for the begin index
	 * @return The begin index
	 */
	public int getBegin() {
		return begin;
	}

	/**
	 * Setter for the begin index
	 * @param begin The begin index
	 */
	public void setBegin(int begin) {
		this.begin = begin;
	}

	/**
	 * Getter for the end index
	 * @return The end index
	 */
	public int getEnd() {
		return end;
	}

	/**
	 * Setter for the end index
	 * @param end The end index
	 */
	public void setEnd(int end) {
		this.end = end;
	}

	/**
	 * Getter for the value
	 * @return The value
	 */
	public String getValue() {
		return value;
	}

	/**
	 * Setter for the value
	 * @param value The value
	 */
	public void setValue(String value) {
		this.value = value;
	}

	/**
	 * Getter for the type
	 * @return The type
	 */
	public SubexpressionType getType() {
		return type;
	}

	/**
	 * Setter for the type
	 * @param type The type
	 */
	public void setType(SubexpressionType type) {
		this.type = type;
	}
	
	
}
