package de.upb.infexba.ml.feature;

import java.util.Arrays;
import java.util.HashMap;
import java.util.TreeSet;

/**
 * The FeatureHandler
 * 
 * @author kabu
 * 
 */
abstract public class FeatureHandler {

	public static final short NO_FACTORS = 0; // Standard
	public static final short MY_NORMALIZATION = 1;
	public static final short CALCULATED_MAXIMA_MUSIC = 2;
	public static final short CALCULATED_MAXIMA_SMARTPHONE = 3;
	public static final short CALCULATED_AVERAGE_MUSIC = 4;
	public static final short CALCULATED_AVERAGE_SMARTPHONE = 5;

	protected short normalizationMode = NO_FACTORS;

	/**
	 * set of the features that are handled by this featureHandler
	 */
	protected TreeSet<String> features = new TreeSet<String>();

	/**
	 * true if and only if only the features given in the set above shall be handled, otherwise all features that can be
	 * handled will be computed.
	 */
	protected boolean handles_given_features = false;

	/**
	 * saves the feature values in a mapping feature -> value
	 */
	protected HashMap<String, Double> feature_map = new HashMap<String, Double>();
	

	public FeatureHandler() {
	}

	public FeatureHandler(String[] features) {
		this.handles_given_features = (features != null);
		this.setFeatures(features);
	}

	public void setNormalizationMode(short mode) {
		this.normalizationMode = mode;
	}

	public void setFeatures(String[] features) {
		this.handles_given_features = (features != null);
		this.features.clear();
		if (features != null)
			this.features.addAll(Arrays.asList(features));
		else
			this.features = null;
	}

	public void addFeature(String feature) {
		this.features.add(feature);
		this.handles_given_features = true;
	}

	abstract public TreeSet<String> getFeatures();

	public boolean handles(String feature) {
		if (this.handles_given_features)
			return features.contains(feature);
		else
			return canHandle(feature);
	}

	abstract public boolean canHandle(String feature);

	public void clearFeatures() {
		this.features.clear();
		this.handles_given_features = false;
	}
	
//	TODO:
//	abstract public void handle(List<Object> objects);

	protected void increaseInFeatureMap(String feature, Double value) {
		if (this.handles(feature))
			this.increase(feature_map, feature, value);
	}

	protected void increaseInMap(HashMap<String, Double> map, String feature, Double value) {
		if (this.handles(feature))
			this.increase(map, feature, value);
	}

	private void increase(HashMap<String, Double> map, String feature, Double value) {
		if (map.containsKey(feature))
			map.put(feature, map.get(feature) + value);
		else
			map.put(feature, value);
	}

	public double getFromFeatureMap(String feature) {
		if (feature_map.containsKey(feature))
			return feature_map.get(feature);
		return 0.;
	}

	public void clearFeatureMap() {
		this.feature_map.clear();
	}

	abstract public double getNormalizedValue(String feature, double value, Double additionalInfo);

}
