package de.upb.infexba.ml.feature.ngram;

import java.util.HashMap;
import java.util.TreeSet;

import org.apache.uima.jcas.JCas;

import de.upb.infexba.ml.IntentionFeatureCalculator;
import de.upb.infexba.ml.feature.GenreFeatureHandler;

/**
 * Abstract class of an Ngram-Handler.
 * 
 * @author kabu
 * 
 */
abstract public class NgramHandler extends GenreFeatureHandler {

	protected HashMap<String, Double> informational = new HashMap<String, Double>();
	protected HashMap<String, Double> commercial = new HashMap<String, Double>();
	protected HashMap<String, Double> personal = new HashMap<String, Double>();
	protected HashMap<String, Double> tmp = new HashMap<String, Double>();

	protected int n = 0;

	NgramHandler(int n) {
		this.n = n;
	}

	public int n() {
		return this.n;
	}

	abstract public boolean canHandle(String feature);

	public TreeSet<String> getFeatures() {
		if (this.handles_given_features)
			return this.features;
		else
			return new TreeSet<String>(this.feature_map.keySet());
	}

	abstract String getFeatureName(Object[] ngram);

	public void handle(JCas jcas, String classification) {
		if (classification == null || classification.isEmpty())
			this.handleInMap(jcas, feature_map);
		else {
			HashMap<String, Double> map = this.getMapByName(classification);
			this.handleInMap(jcas, map);
		}
	}
	
	abstract protected void handleInMap(JCas jcas, HashMap<String, Double> map);

	protected HashMap<String, Double> getMapByName(String classification, short kind) {
		if (classification.equals(IntentionFeatureCalculator.PERSONAL))
			return personal;
		if (classification.equals(IntentionFeatureCalculator.COMMERCIAL))
			return commercial;
		if (classification.equals(IntentionFeatureCalculator.INFORMATIONAL))
			return informational;
		return null;
	}

}