package de.upb.infexba.ml.feature.vocabulary;

import de.upb.infexba.ml.feature.partofspeech.PartOfSpeechConstants;

public class SkipLists {

	/**
	 * Defines the POS types for which by default the following holds: tokens (i.e. word and lemmas) that have one of
	 * this POS types are NOT counted. To add an Exception assign a lemma/word-key in get_correct_pos_and_key to a
	 * specific token!!!
	 */
	public static String[] POS_SKIP_LIST_FOR_TOKENS = { PartOfSpeechConstants.SATZENDE, PartOfSpeechConstants.SATZINTERN, PartOfSpeechConstants.KOMMA,
			PartOfSpeechConstants.XY, "NE", "CARD", "FM" };

	/**
	 * Music-Specific skip-list.
	 * 
	 * If chosen as a skip-list, tokens that have a word key that appears in the following list, won't be counted as a
	 * word and also not as lemma!
	 */
	public static final String[] WORD_KEY_SKIP_LIST_MUSIC = { "‘|w", "SOME_POS|w", "ashanti|w", "lais|w", "under|w", "bee|w", "black|w", "big|w", "over|w",
			"avalon|w", "ärzte|w", "boygroup|w", "babies|w", "yorker|w", "weihnacht|w", "weihnachten|w", "which|w", "crowds|w", "scheibe|w", "lyrics|w",
			"boy|w", "radar|w", "dezember|w", "death|w", "quo|w", "blige|w", "gang|w", "religion|w", "us|w", "anti|w", "archive|w", "herbst|w", "bierbeben|w",
			"apoptygma|w", ",|w", "gees|w", "studioalben|w", "high|w", "arch|w", "helden|w", "where|w", "januar|w", "beyond|w", "harten|w", "londoner|w",
			"status|w", "januar|w", "basement|w", "raps|w", "schlager|w", "stücken|w", "brut|w", "höre|w", "direct|w", "order|w", "j|w", "-|w", "+|w", "–|w",
			"‚|w", "künstlerin|w", "enemy|w", "loose|w", "formation|w", "winter|w", "bourne|w", "mutter|w", "did|w", "shows|w", "traum|w", "jive|w",
			"charts|w", "at|w", "she|w", "single|w", "or|w", "debütalbum|w", "singles|w", "let|w", "drummer|w", "sängerin|w", "produziert|w", "berliner|w",
			"boys|w", "r|w", "by|w", "menschen|w", "b|w", "hit|w", "studioalbum|w", "publikum|w", "studio|w", "bon|w", "produzenten|w", "end|w", "show|w",
			"people|w", "tour|w", "produzent|w", "cds|w", "animal|w", "gott|w", "material|w", "rap|w", "night|w", "scooter|w", "techno|w", "hardcore|w",
			"records|w", "if|w", "to|w", "as|w", "label|w", "textlich|w", "künstler|w", "machine|w", "hip|w", "mainstream|w", "radio|w", "nein|w", "me|w",
			"vocals|w", "musikalischen|w", "we|w", "be|w", "not|w", "gitarrist|w", "go|w", "alter|w", "like|w", "booklet|w", "albums|w", "gekauft|w", "are|w",
			"szene|w", "on|w", "sterne|w", "underground|w", "niveau|w", "platz|w", "longplayer|w", "metal|w", "amazon|w", "queen|w", "riffs|w", "folk|w",
			"eat|w", "opener|w", "old|w", "m|w", /* new */"clubs|w", "chor|w", "musical|w", "controlling|w", "hancock|w", "gt|w", "vampire|w", "more|w",
			"stripes|w", "dancefloor|w", "blink|w", "groove|w", "underworld|w", "angel|w", "own|w", "heute2|w", " |w", "review|w" };

	/**
	 * Really specific.
	 * 
	 * If chosen as a skip-list, tokens that have a word key that appears in the following list, won't be counted as a
	 * word and also not as lemma!
	 */
	public static final String[] WORD_KEY_SKIP_LIST_SPECIFIC = { "‘|w", "SOME_POS|w", "ashanti|w", "lais|w", "under|w", "bee|w", "black|w", "big|w", "over|w",
			"avalon|w", "ärzte|w", "babies|w", "yorker|w", "weihnacht|w", "weihnachten|w", "which|w", "crowds|w", "boy|w", "radar|w", "dezember|w", "death|w",
			"quo|w", "blige|w", "gang|w", "religion|w", "us|w", "anti|w", "archive|w", "herbst|w", "bierbeben|w", "apoptygma|w", ",|w", "gees|w", "high|w",
			"arch|w", "helden|w", "where|w", "januar|w", "beyond|w", "londoner|w", "status|w", "januar|w", "basement|w", "brut|w", "direct|w", "order|w",
			"j|w", "-|w", "+|w", "–|w", ",|w", "enemy|w", "loose|w", "winter|w", "bourne|w", "mutter|w", "did|w", "traum|w", "jive|w", "at|w", "she|w", "or|w",
			"let|w", "berliner|w", "boys|w", "r|w", "by|w", "b|w", "bon|w", "end|w", "people|w", "animal|w", "gott|w", "night|w", "scooter|w", "if|w", "to|w",
			"as|w", "machine|w", "nein|w", "me|w", "we|w", "be|w", "not|w", "go|w", "alter|w", "like|w", "are|w", "on|w", "metal|w", "sterne|w", "queen|w",
			"riffs|w", "folk|w", "eat|w", "old|w", "m|w", "controlling|w", "hancock|w", "gt|w", "vampire|w", "stripes|w", "dancefloor|w", "blink|w", "more|w",
			"groove|w", "underworld|w", "angel|w", "own|w", "no|w", " |w", "heute2|w", "hardcore|w", }; // "review|w"};

	/**
	 * Tokens that have a lemma key that appears in the following list, won't be counted as lemma and also not as words!
	 */
	public static String[] LEMMA_KEY_SKIP_LIST_MUSIC = { "everything|l", "musikszene|l", "performance|l", "tenor|l", "twilight|l", "knopfler|l", "than|l",
			"röyksopp|l", "without|l", "that|l", "platin|l", "november|l", "has|l", "britisch|l", ",|l", "elektronisch|l", "mende|l", "gleichnamig|l", ",|l" };

	/**
	 * Tokens that have a lemma key that appears in the following list, won't be counted as lemma and also not as words!
	 */
	public static String[] LEMMA_KEY_SKIP_LIST_SPECIFIC = { "everything|l", "twilight|l", "knopfler|l", "than|l", "röyksopp|l", "without|l", "that|l",
			"platin|l", "november|l", "has|l", "britisch|l", ",|l", "elektronisch|l", "mende|l", ",|l" };

	public static final String[] SATZZEICHEN = { "quote|w", "exclamation_mark|w", "dot|w", "komma|w", "semicolon|w", "paranthesis|w", "question_mark|w",
			"colon|w" };

}
